#!/usr/bin/env python3
import fileinput
import json
from itertools import zip_longest
from subprocess import check_output

from rapidtables import print_table

if __name__ == '__main__':

    lines = fileinput.input()
    what = next(lines).split(' ')[1]

    header_line = next(lines)
    while len(header_line) < 10:
        header_line = next(lines)

    headers = {}
    for header in [x.strip() for x in header_line.split('  ') if x]:
        i = header_line.index(header)
        headers[header] = i

    result = []
    for line in lines:
        if len(line) < 1:
            continue
        if line.startswith('TIP:'):
            continue

        values = []
        for h in headers:
            x = line[headers[h]:].split('  ')[0].strip()
            values.append(x)

        new_entry = {header: value.split(', ') for header, value in zip(headers, values)}

        for current in zip_longest(*new_entry.values(), fillvalue=''):
            result.append({header: value for header, value in zip(headers, current)})

    result.append({})

    print_table(result, tablefmt='md')



from distutils.core import setup

setup(
    name='cf_pretty',
    packages=['cf_pretty'],
    version='0.1',
    license='MIT',
    description='makes cf cli output more readable',
    author='Lukas Benedix',
    author_email='pypi@l3q.de',
    url='https://github.com/lbenedix/cf_pretty',
    download_url='https://github.com/lbenedix/cf_pretty/archive/v_01.tar.gz',
    keywords=['CF', 'CLOUD FOUNDRY', 'KEYWORDS'],
    install_requires=[
        'rapidtables',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # Again, pick a license
        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
    ],
)
